@@ -189,9 +189,11 @@ def cli(ctx, **kwargs):
     return ctx
 
 
-def validate_version(ctx, param, version):
+def validate_semver_major_minor_patch(ctx, param, version):
     """
-    For non-None, non-auto values, ensures that first 3 version segments are integers (with optional v prefix)
+    For non-None, non-auto values, ensures that the incoming parameter meets the criteria vX.Y.Z or X.Y.Z.
+    If minor or patch is not supplied, the value is modified to possess
+    minor.major to meet semver requirements.
     :param ctx: Click context
     :param param: The parameter specified on the command line
     :param version: The version specified on the command line
@@ -203,12 +205,15 @@ def validate_version(ctx, param, version):
     vsplit = version.split(".")
     try:
         int(vsplit[0].lstrip('v'))
-        int('0' if len(vsplit) < 2 else vsplit[1])
-        int('0' if len(vsplit) < 3 else vsplit[2])
+        minor_version = int('0' if len(vsplit) < 2 else vsplit[1])
+        patch_version = int('0' if len(vsplit) < 3 else vsplit[2])
     except ValueError:
         raise click.BadParameter('Expected integers in version fields')
 
-    return version
+    if len(vsplit) > 3:
+        raise click.BadParameter('Expected X, X.Y, or X.Y.Z (with optional "v" prefix)')
+
+    return f'{vsplit[0]}.{minor_version}.{patch_version}'
 
 
 option_commit_message = click.option("--message", "-m", cls=RemoteRequired, metavar='MSG', help="Commit message for dist-git.")
@@ -252,7 +257,7 @@ def rpms_clone_sources(runtime, output_yml):
 
 
 @cli.command("rpms:build", help="Build rpms in the group or given by --rpms.")
-@click.option("--version", metavar='VERSION', default=None, callback=validate_version,
+@click.option("--version", metavar='VERSION', default=None, callback=validate_semver_major_minor_patch,
               help="Version string to populate in specfile.", required=True)
 @click.option("--release", metavar='RELEASE', default=None,
               help="Release label to populate in specfile.", required=True)
@@ -315,7 +320,7 @@ def images_push_distgit(runtime):
 @cli.command("images:update-dockerfile", short_help="Update a group's distgit Dockerfile from metadata.")
 @click.option("--stream", metavar="ALIAS REPO/NAME:TAG", nargs=2, multiple=True,
               help="Associate an image name with a given stream alias.  [multiple]")
-@click.option("--version", metavar='VERSION', default=None, callback=validate_version,
+@click.option("--version", metavar='VERSION', default=None, callback=validate_semver_major_minor_patch,
               help="Version string to populate in Dockerfiles. \"auto\" gets version from atomic-openshift RPM")
 @click.option("--release", metavar='RELEASE', default=None,
               help="Release label to populate in Dockerfiles (or + to bump).")
@@ -450,7 +455,7 @@ def config_scan_source_changes(runtime, as_yaml):
 @cli.command("images:rebase", short_help="Refresh a group's distgit content from source content.")
 @click.option("--stream", metavar="ALIAS REPO/NAME:TAG", nargs=2, multiple=True,
               help="Associate an image name with a given stream alias.  [multiple]")
-@click.option("--version", metavar='VERSION', default=None, callback=validate_version,
+@click.option("--version", metavar='VERSION', default=None, callback=validate_semver_major_minor_patch,
               help="Version string to populate in Dockerfiles. \"auto\" gets version from atomic-openshift RPM")
 @click.option("--release", metavar='RELEASE', default=None, help="Release string to populate in Dockerfiles.")
 @click.option("--repo-type", metavar="REPO_TYPE", envvar="OIT_IMAGES_REPO_TYPE",
